=======
History
=======

Unreleased
----------

0.2.1 (2017-10-24)
------------------

* Fix README.rst documentation

0.2.0 (2017-10-24)
------------------

* Add -l/--line-number argument instead of requiring that the line number sequence is the first argument.

0.1.0 (2017-07-01)
------------------

* First release on PyPI.
